<?php

include __DIR__."/builtin_extensions.inc";

class A_DOMProcessingInstruction extends DOMProcessingInstruction {
  public $___x;
}
test("DOMProcessingInstruction", "Foo");
